/// <reference types="koa__router" />
import Router from '@koa/router';
import Koa from 'koa';
import type { NextApiRequest, NextApiResponse } from 'next';
declare module 'koa' {
    type IncomingMessage = NextApiRequest;
    type ServerResponse = NextApiResponse;
    interface Request extends Koa.BaseRequest {
        body?: any;
    }
}
export { Router };
export { Koa };
export declare type KoaOptions = {
    env?: string;
    keys?: string[];
    proxy?: boolean;
    subdomainOffset?: number;
    proxyIpHeader?: string;
    maxIpsCount?: number;
};
export declare type KoaApiOptions = {
    koa?: KoaOptions;
    attachBody?: boolean;
    router?: Router.RouterOptions;
    routerAllowedMethods?: Router.RouterAllowedMethodsOptions;
};
export declare class KoaApi<TState extends Koa.DefaultState = Koa.DefaultState, TContext extends Koa.DefaultContext = Koa.DefaultContext> extends Koa<TState, TContext> {
    router: Router<TState, TContext>;
    protected firstRun: boolean;
    protected options: KoaApiOptions;
    constructor(options?: KoaApiOptions);
    /**
     * Run koa api with request and response objects
     * @param req - nextjs request
     * @param res - nextjs response
     */
    run(req: NextApiRequest, res: NextApiResponse): Promise<unknown>;
}
/**
 * Helper function for Next.js api routes that automatically runs the KoaApi.
 * It should be used as default export from the Next.js api route file
 * @param koa - KoaApi to run
 */
export declare function withKoaApi(koa: KoaApi<any, any>): (req: NextApiRequest, res: NextApiResponse) => Promise<unknown>;
